/*
**                      Softwarepraktikum iMaze
**                              1993/94
**                Joerg Czeranski    Hans-Ulrich Kiel
**
** Datei: signale.h
**
** Kommentar:
**  Definiert moegliche Eingabe-Signale
*/


static char sccsid_signale[] = "@(#)signale.h	1.9 26 May 1994";


#define AKTIONSSIGNALANZ 10 /* Anzahl der frei verfuegbaren Signale
                               (diese Signale sind fuer die Kompabilitaet
                               mit zukuenfigen Versionen vorgesehen) */

#define SCHUSSSIGNAL   0    /* Spieler feuert einen Schuss ab */
#define VORSIGNAL      1    /* Spieler geht einen Schritt vorwaerts */
#define ZURUECKSIGNAL  2    /* Spieler geht einen Schritt rueckwaerts */
#define LINKSSIGNAL    3    /* Spieler dreht nach links */
#define RECHTSSIGNAL   4    /* Spieler dreht nach rechts */
#define STOPSIGNAL     5    /* Spiel temporaer verlassen */
#define WEITERSIGNAL   6    /* ins Spiel zurueckkehren */

#define AKTIONSSIGNALE 7 /* Offset */
#define SIGNALANZ      (AKTIONSSIGNALE + AKTIONSSIGNALANZ)
